Client

Struct Client 

#[repr(C)]
pub struct Client { pub(super) run: extern "C" fn(BridgeConfig<'_>) -> Buffer, }
🔬This is a nightly-only experimental API. (proc_macro_internals)
A client-side RPC entry-point, which may be using a different proc_macro from the one used by the server, but can be invoked compatibly.

Note that the input and output type parameters are erased. They do not participate in the ABI, so while using the wrong runN method will likely result in a panic, it will not result in UB.

Fields

run: extern "C" fn(BridgeConfig<'_>) -> Buffer
🔬This is a nightly-only experimental API. (proc_macro_internals)

Implementations

Source

impl Client

pub const fn expand1(f: impl Fn(TokenStream) -> TokenStream + Copy) -> Self

🔬This is a nightly-only experimental API. (proc_macro_internals)
pub const fn expand2( f: impl Fn(TokenStream, TokenStream) -> TokenStream + Copy, ) -> Self

🔬This is a nightly-only experimental API. (proc_macro_internals)
Source

impl Client

pub fn run1<S>( &self, strategy: &impl ExecutionStrategy, server: S, input: S::TokenStream, force_show_panics: bool, ) -> Result<S::TokenStream, PanicMessage>
where S: Server,

🔬This is a nightly-only experimental API. (proc_macro_internals)
pub fn run2<S>( &self, strategy: &impl ExecutionStrategy, server: S, input: S::TokenStream, input2: S::TokenStream, force_show_panics: bool, ) -> Result<S::TokenStream, PanicMessage>
where S: Server,

🔬This is a nightly-only experimental API. (proc_macro_internals)